import { PublicKey } from '@solana/web3.js';
import { Nft } from '../models';
import { Operation, OperationHandler } from '../../../types';
declare const Key: "FindNftByAssetIdOperation";
/**
 * Finds an NFT or an SFT by its mint address.
 *
 * ```ts
 * const nft = await metaplex
 *   .nfts()
 *   .findByAssetId({ assetId };
 * ```
 *
 * @group Operations
 * @category Constructors
 */
export declare const findNftByAssetIdOperation: import("../../../types").OperationConstructor<FindNftByAssetIdOperation, "FindNftByAssetIdOperation", FindNftByAssetIdInput, Nft>;
/**
 * @group Operations
 * @category Types
 */
export type FindNftByAssetIdOperation = Operation<typeof Key, FindNftByAssetIdInput, FindNftByAssetIdOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type FindNftByAssetIdInput = {
    /** The id of an asset. */
    assetId: PublicKey;
};
/**
 * @group Operations
 * @category Outputs
 */
export type FindNftByAssetIdOutput = Nft;
/**
 * @group Operations
 * @category Handlers
 */
export declare const findNftByAssetIdOperationHandler: OperationHandler<FindNftByAssetIdOperation>;
export {};
